@@ -30,6 +30,7 @@ import subprocess
 import sys
 import shutil
 import json
+import sqlite3
 from pathlib import Path
 from typing import Optional, List, Dict, Any
 
@@ -494,7 +495,6 @@ def create_agent_files(project_path: Path, mcp_servers: List[str]) -> None:
             "evaluator": create_evaluator_content(mcp_servers),
             "reflector": create_reflector_content(mcp_servers),
             "curator": create_curator_content(mcp_servers),
-            "test-generator": create_test_generator_content(mcp_servers),
             "documentation-reviewer": create_documentation_reviewer_content(mcp_servers)
         }
 
@@ -898,62 +898,7 @@ Return JSON with:
 """
 
 
-def create_test_generator_content(mcp_servers: List[str]) -> str:
-    """Create test-generator agent content"""
-    mcp_section = ""
-    if any(s in mcp_servers for s in ["cipher", "context7"]):
-        mcp_section = """
-# MCP INTEGRATION
-
-**Use these tools for test generation:**
-"""
-        if "cipher" in mcp_servers:
-            mcp_section += """
-1. **mcp__cipher__cipher_memory_search** - Find similar test patterns
-   - Query: "test pattern [feature_type]"
-"""
-        if "context7" in mcp_servers:
-            mcp_section += """
-2. **mcp__context7__get-library-docs** - Verify testing framework usage
-   - Ensure correct test syntax for language/framework
-"""
-
-    return f"""---
-name: test-generator
-description: Generates comprehensive test suites for Actor output
-tools: Read, Write, Edit, Bash, Grep, Glob
-model: sonnet
----
-
-# IDENTITY
-
-You are a test automation specialist who creates comprehensive, maintainable test suites.
-{mcp_section}
-# ROLE
-
-Generate tests for Actor implementations covering:
-- Unit tests (individual functions)
-- Integration tests (component interactions)
-- Edge cases and error handling
-- Security-critical paths (100% coverage required)
-
-## Test Strategy
-
-1. **AAA Pattern**: Arrange, Act, Assert
-2. **Coverage Targets**:
-   - Critical code: 100%
-   - High priority: 90%
-   - Medium priority: 80%
-3. **Edge Cases**: Empty inputs, null values, boundaries
-
-## Output Format (JSON)
-
-Return JSON with:
-- approach: Test strategy for this code
-- test_files: Array of {{file_path, content, test_type}}
-- coverage_analysis: Expected coverage percentage
-- testing_notes: Special considerations
-"""
+# Note: test-generator agent removed
 
 
 def create_documentation_reviewer_content(mcp_servers: List[str]) -> str:
@@ -1170,6 +1115,18 @@ def install_hooks(project_path: Path, with_hooks: bool = True) -> int:
         dest_file.chmod(dest_file.stat().st_mode | stat.S_IEXEC | stat.S_IXGRP | stat.S_IXOTH)
         hooks_count += 1
 
+    # Copy helpers directory (Python helper scripts)
+    helpers_src = hooks_template_dir / "helpers"
+    if helpers_src.exists() and helpers_src.is_dir():
+        helpers_dest = hooks_dir / "helpers"
+        if helpers_dest.exists():
+            shutil.rmtree(helpers_dest)
+        shutil.copytree(helpers_src, helpers_dest)
+        # Make Python scripts executable
+        for py_file in helpers_dest.glob("*.py"):
+            if py_file.name != "__init__.py":
+                py_file.chmod(py_file.stat().st_mode | stat.S_IEXEC | stat.S_IXGRP | stat.S_IXOTH)
+
     # Copy README.md
     readme_src = hooks_template_dir / "README.md"
     if readme_src.exists():
@@ -1278,8 +1235,7 @@ def create_mcp_config(project_path: Path, mcp_servers: List[str]) -> None:
             "orchestrator": [],
             "reflector": [],
             "curator": [],
-            "documentation-reviewer": [],
-            "test-generator": []
+            "documentation-reviewer": []
         },
         "workflow_settings": {
             "always_retrieve_knowledge": True,
@@ -1369,7 +1325,7 @@ def create_mcp_config(project_path: Path, mcp_servers: List[str]) -> None:
                 config["agent_mcp_mappings"][agent].append("claude-reviewer")
 
     if "codex-bridge" in mcp_servers:
-        for agent in ["actor", "predictor", "test-generator"]:
+        for agent in ["actor", "predictor"]:
             if agent in config["agent_mcp_mappings"]:
                 config["agent_mcp_mappings"][agent].append("codex-bridge")
 
@@ -1695,7 +1651,7 @@ def init(
     tracker.add("create-agents", "Create MAP agents")
     tracker.start("create-agents")
     create_agent_files(project_path, selected_mcp_servers)
-    tracker.complete("create-agents", "9 agents")
+    tracker.complete("create-agents", "8 agents")
 
     tracker.add("create-commands", "Create slash commands")
     tracker.start("create-commands")
@@ -1716,6 +1672,36 @@ def init(
         create_mcp_config(project_path, selected_mcp_servers)
         tracker.complete("mcp-config", f"{len(selected_mcp_servers)} servers")
 
+    # Initialize playbook database
+    tracker.add("init-playbook", "Initialize playbook database")
+    tracker.start("init-playbook")
+    try:
+        from mapify_cli.playbook_manager import PlaybookManager
+        playbook_db_path = project_path / ".claude" / "playbook.db"
+        manager = PlaybookManager(db_path=str(playbook_db_path), use_semantic_search=False)
+        manager.close()
+        tracker.complete("init-playbook", "database created")
+    except sqlite3.Error as e:
+        tracker.error("init-playbook", "database error")
+        console.print(f"[red]Error:[/red] Failed to initialize playbook database: {e}")
+        console.print("[yellow]Please check disk space and permissions[/yellow]")
+        raise typer.Exit(1)
+    except PermissionError as e:
+        tracker.error("init-playbook", "permission denied")
+        console.print(f"[red]Error:[/red] Permission denied creating playbook: {e}")
+        console.print("[yellow]Run with appropriate permissions or choose a different directory[/yellow]")
+        raise typer.Exit(1)
+    except OSError as e:
+        tracker.error("init-playbook", "filesystem error")
+        console.print(f"[red]Error:[/red] Could not create playbook directory: {e}")
+        console.print("[yellow]Please check directory permissions[/yellow]")
+        raise typer.Exit(1)
+    except json.JSONDecodeError as e:
+        tracker.error("init-playbook", "invalid JSON")
+        console.print(f"[red]Error:[/red] Corrupted playbook.json file: {e}")
+        console.print("[yellow]Suggestion: Rename or delete .claude/playbook.json and try again[/yellow]")
+        raise typer.Exit(1)
+
     # Initialize git
     if not no_git and git_available:
         tracker.add("git", "Initialize git repository")
@@ -1898,29 +1884,211 @@ def recitation_clear():
     manager.clear_plan()
     console.print_json(data={"status": "success", "message": "Plan cleared"})
 
+
+@recitation_app.command("generate-context")
+def recitation_generate_context():
+    """Generate context.md from project metadata and playbook"""
+    from mapify_cli.recitation_manager import RecitationManager
+    manager = RecitationManager(Path.cwd())
+    try:
+        context_file = manager.generate_context_md()
+        console.print_json(data={
+            "status": "success",
+            "message": "Generated context.md",
+            "file": context_file
+        })
+    except Exception as e:
+        console.print_json(data={
+            "status": "error",
+            "message": f"Failed to generate context.md: {str(e)}"
+        })
+        raise typer.Exit(1)
+
+
+@recitation_app.command("generate-tasks")
+def recitation_generate_tasks():
+    """Regenerate tasks.md from current plan"""
+    from mapify_cli.recitation_manager import RecitationManager
+    manager = RecitationManager(Path.cwd())
+    try:
+        plan = manager.get_plan()
+        if not plan:
+            console.print_json(data={
+                "status": "error",
+                "message": "No active plan to generate tasks from"
+            })
+            raise typer.Exit(1)
+
+        manager._generate_tasks_md(plan)
+        console.print_json(data={
+            "status": "success",
+            "message": "Generated tasks.md",
+            "file": str(manager.tasks_file)
+        })
+    except Exception as e:
+        console.print_json(data={
+            "status": "error",
+            "message": f"Failed to generate tasks.md: {str(e)}"
+        })
+        raise typer.Exit(1)
+
+
+@recitation_app.command("get-docs")
+def recitation_get_docs():
+    """Get all dev docs content (plan + context + tasks)"""
+    from mapify_cli.recitation_manager import RecitationManager
+    manager = RecitationManager(Path.cwd())
+    try:
+        docs = manager.get_dev_docs()
+        console.print_json(data={
+            "status": "success",
+            "docs": docs
+        })
+    except Exception as e:
+        console.print_json(data={
+            "status": "error",
+            "message": f"Failed to get dev docs: {str(e)}"
+        })
+        raise typer.Exit(1)
+
+
+@recitation_app.command("checkpoint")
+def recitation_checkpoint():
+    """Show current MAP workflow state and recovery instructions for post-compaction"""
+    from mapify_cli.recitation_manager import RecitationManager
+    import os
+
+    manager = RecitationManager(Path.cwd())
+    map_dir = Path.cwd() / ".map"
+
+    # Check if .map directory exists
+    if not map_dir.exists():
+        console.print("[yellow]⚠️  No active MAP workflow found[/yellow]")
+        console.print("\nThe `.map/` directory doesn't exist yet.")
+        console.print("Start a MAP workflow with: [cyan]/map-feature[/cyan], [cyan]/map-debug[/cyan], or [cyan]/map-refactor[/cyan]")
+        raise typer.Exit(0)
+
+    # Define files to check
+    files_to_check = {
+        "plan_json": manager.plan_json,
+        "plan_md": manager.plan_file,
+        "context_md": manager.context_file,
+        "tasks_md": manager.tasks_file
+    }
+
+    # Check which files exist
+    existing_files = {name: path for name, path in files_to_check.items() if path.exists()}
+
+    if not existing_files:
+        console.print("[yellow]⚠️  MAP workflow directory exists but no state files found[/yellow]")
+        console.print(f"\nDirectory: {map_dir.absolute()}")
+        console.print("Expected files are missing. The workflow may not have been initialized properly.")
+        raise typer.Exit(0)
+
+    # Print checkpoint header
+    console.print("\n[bold green]📍 MAP Workflow Checkpoint[/bold green]")
+    console.print("=" * 60)
+
+    # Print file locations
+    console.print("\n[bold]📁 State Files (absolute paths):[/bold]")
+    for name, path in existing_files.items():
+        file_size = path.stat().st_size
+        console.print(f"  • {path.absolute()} ([dim]{file_size} bytes[/dim])")
+
+    # Show current task status if plan exists
+    if "plan_json" in existing_files:
+        try:
+            plan = manager.get_plan()
+            if plan:
+                console.print(f"\n[bold]🎯 Current Task:[/bold] {plan.goal}")
+                console.print(f"[bold]📊 Progress:[/bold] {plan.current_subtask_id}/{len(plan.subtasks)} subtasks")
+
+                # Show current subtask
+                current = next((s for s in plan.subtasks if s.id == plan.current_subtask_id), None)
+                if current:
+                    console.print(f"[bold]▶️  Active:[/bold] {current.description} [{current.status}]")
+        except Exception as e:
+            console.print(f"[yellow]⚠️  Could not parse plan: {str(e)}[/yellow]")
+
+    # Print file contents with headers
+    console.print("\n[bold]📄 File Contents:[/bold]")
+    console.print("-" * 60)
+
+    for name, path in existing_files.items():
+        console.print(f"\n[bold cyan]### {path.name}[/bold cyan]")
+        try:
+            content = path.read_text()
+            # Truncate very long files
+            if len(content) > 2000:
+                console.print(content[:2000])
+                console.print(f"\n[dim]... (truncated, {len(content) - 2000} more chars)[/dim]")
+            else:
+                console.print(content)
+        except Exception as e:
+            console.print(f"[red]Error reading file: {str(e)}[/red]")
+
+    # Print recovery instructions
+    console.print("\n" + "=" * 60)
+    console.print("[bold green]🔄 Recovery Instructions (for post-compaction):[/bold green]")
+    console.print("\nAfter context compaction, paste this to Claude:\n")
+
+    recovery_message = f"""```
+Continue MAP workflow from checkpoint:
+
+@{manager.plan_file.absolute()}"""
+
+    if "context_md" in existing_files:
+        recovery_message += f"\n@{manager.context_file.absolute()}"
+    if "tasks_md" in existing_files:
+        recovery_message += f"\n@{manager.tasks_file.absolute()}"
+
+    recovery_message += "\n```"
+
+    console.print(recovery_message)
+    console.print("\n[dim]Claude will automatically resume from where you left off.[/dim]")
+    console.print("=" * 60 + "\n")
+
+
 # Playbook commands
 
 @playbook_app.command("stats")
 def playbook_stats():
     """Show playbook statistics"""
-    playbook_path = Path.cwd() / ".claude" / "playbook.json"
-    if not playbook_path.exists():
-        console.print_json(data={"error": "Playbook not found"})
+    from mapify_cli.playbook_manager import PlaybookManager
+
+    playbook_db_path = Path.cwd() / ".claude" / "playbook.db"
+    playbook_json_path = Path.cwd() / ".claude" / "playbook.json"
+
+    # Check for playbook.db first (primary storage)
+    if not playbook_db_path.exists():
+        # Backward compatibility: check if old playbook.json exists
+        if playbook_json_path.exists():
+            console.print_json(data={
+                "error": "Found legacy playbook.json. Run 'mapify init' to migrate to playbook.db"
+            })
+        else:
+            console.print_json(data={"error": "Playbook not found. Initialize with 'mapify init'"})
         raise typer.Exit(1)
-    playbook = json.loads(playbook_path.read_text())
-    total = sum(len(section["bullets"]) for section in playbook.get("sections", {}).values())
-    stats = {"total_bullets": total, "sections": len(playbook.get("sections", {})), "metadata": playbook.get("metadata", {})}
+
+    # Use PlaybookManager with db_path (SQLite backend)
+    manager = PlaybookManager(db_path=str(playbook_db_path))
+    total = sum(len(section["bullets"]) for section in manager.playbook.get("sections", {}).values())
+    stats = {
+        "total_bullets": total,
+        "sections": len(manager.playbook.get("sections", {})),
+        "metadata": manager.playbook.get("metadata", {})
+    }
     console.print_json(data=stats)
 
 @playbook_app.command("search")
 def playbook_search(query: str, top_k: int = typer.Option(5, help="Number of results")):
     """Search playbook for relevant patterns"""
     from mapify_cli.playbook_manager import PlaybookManager
-    playbook_path = Path.cwd() / ".claude" / "playbook.json"
-    if not playbook_path.exists():
+    playbook_db_path = Path.cwd() / ".claude" / "playbook.db"
+    if not playbook_db_path.exists():
         console.print("No patterns found (playbook not initialized)")
         return
-    manager = PlaybookManager(playbook_path)
+    manager = PlaybookManager(db_path=str(playbook_db_path))
     results = manager.get_relevant_bullets(query, limit=top_k)
     if not results:
         console.print("No patterns found matching your query")
@@ -1931,14 +2099,278 @@ def playbook_search(query: str, top_k: int = typer.Option(5, help="Number of res
 def playbook_sync(threshold: int = typer.Option(5, help="Minimum helpful count")):
     """Show high-quality patterns ready for cross-project sync"""
     from mapify_cli.playbook_manager import PlaybookManager
-    playbook_path = Path.cwd() / ".claude" / "playbook.json"
-    if not playbook_path.exists():
-        console.print_json(data={"status": "error", "message": "Playbook not found"})
+    playbook_db_path = Path.cwd() / ".claude" / "playbook.db"
+    playbook_json_path = Path.cwd() / ".claude" / "playbook.json"
+
+    # Check for playbook.db first (primary storage)
+    if not playbook_db_path.exists():
+        # Backward compatibility: check if old playbook.json exists
+        if playbook_json_path.exists():
+            console.print_json(data={
+                "status": "error",
+                "message": "Found legacy playbook.json. Run 'mapify init' to migrate to playbook.db"
+            })
+        else:
+            console.print_json(data={"status": "error", "message": "Playbook not found. Initialize with 'mapify init'"})
         raise typer.Exit(1)
-    manager = PlaybookManager(playbook_path)
+
+    manager = PlaybookManager(db_path=str(playbook_db_path))
     patterns = manager.get_bullets_for_sync(threshold=threshold)
     console.print_json(data={"threshold": threshold, "count": len(patterns), "patterns": [{"id": p.get("id"), "helpful_count": p.get("helpful_count")} for p in patterns]})
 
+@playbook_app.command("query")
+def playbook_query(
+    query_text: str = typer.Argument(..., help="Search query"),
+    sections: List[str] = typer.Option([], "--section", help="Filter by section (can specify multiple)"),
+    limit: int = typer.Option(5, "--limit", help="Maximum results to return"),
+    mode: str = typer.Option("local", "--mode", help="Search mode: local, cipher, or hybrid"),
+    format_output: str = typer.Option("markdown", "--format", help="Output format: markdown or json"),
+    min_quality: int = typer.Option(0, "--min-quality", help="Minimum quality score (helpful - harmful)"),
+):
+    """Query playbook using FTS5 full-text search with optional cipher integration
+
+    Examples:
+        mapify playbook query "JWT authentication" --limit 5
+        mapify playbook query "error handling" --mode hybrid --limit 10
+        mapify playbook query "API design" --section ARCHITECTURE_PATTERNS --section IMPLEMENTATION_PATTERNS
+    """
+    from mapify_cli.playbook_manager import PlaybookManager
+    from mapify_cli.playbook_query import PlaybookQuery, SearchMode
+
+    playbook_db_path = Path.cwd() / ".claude" / "playbook.db"
+    playbook_json_path = Path.cwd() / ".claude" / "playbook.json"
+
+    # Check for playbook.db first (primary storage)
+    if not playbook_db_path.exists():
+        # Backward compatibility: check if old playbook.json exists
+        if playbook_json_path.exists():
+            console.print("[yellow]Warning:[/yellow] Found legacy playbook.json. Run 'mapify init' to migrate to playbook.db")
+        else:
+            console.print("[yellow]Warning:[/yellow] Playbook not found. Initialize with 'mapify init'")
+        raise typer.Exit(1)
+
+    try:
+        # Map mode string to SearchMode enum
+        mode_map = {
+            "local": SearchMode.PLAYBOOK_ONLY,
+            "cipher": SearchMode.CIPHER_ONLY,
+            "hybrid": SearchMode.HYBRID
+        }
+        search_mode = mode_map.get(mode.lower(), SearchMode.PLAYBOOK_ONLY)
+
+        # Create query
+        query = PlaybookQuery(
+            query=query_text,
+            sections=list(sections) if sections else None,
+            limit=limit,
+            search_mode=search_mode,
+            min_quality_score=min_quality
+        )
+
+        # Execute query
+        manager = PlaybookManager(db_path=str(playbook_db_path))
+        response = manager.query(query)
+
+        # Format output
+        if format_output == "json":
+            # JSON output
+            results_json = {
+                "query": query_text,
+                "metadata": response.metadata,
+                "results": [
+                    {
+                        "id": r.id,
+                        "section": r.section,
+                        "content": r.content,
+                        "code_example": r.code_example,
+                        "quality_score": r.quality_score,
+                        "relevance_score": r.relevance_score,
+                        "combined_score": r.combined_score,
+                        "source": r.source
+                    }
+                    for r in response.results
+                ]
+            }
+            console.print_json(data=results_json)
+        else:
+            # Markdown output (default)
+            if not response.results:
+                console.print("[yellow]No results found[/yellow]")
+                return
+
+            console.print(f"# Query Results: {query_text}\n")
+            console.print(f"**Found {len(response.results)} results in {response.metadata['total_time_ms']}ms**\n")
+            console.print(f"*Search method: {response.metadata['search_method']}*\n")
+
+            for i, result in enumerate(response.results, 1):
+                console.print(f"## {i}. [{result.id}] Score: {result.combined_score:.2f}\n")
+                console.print(f"**Section:** {result.section}\n")
+                console.print(f"**Quality:** {result.quality_score} | **Relevance:** {result.relevance_score:.2f} | **Source:** {result.source}\n")
+                console.print(f"{result.content}\n")
+
+                if result.code_example:
+                    console.print("```")
+                    console.print(result.code_example)
+                    console.print("```\n")
+
+                console.print("---\n")
+
+    except ValueError as e:
+        console.print(f"[red]Error:[/red] {str(e)}")
+        raise typer.Exit(1)
+    except Exception as e:
+        console.print(f"[red]Unexpected error:[/red] {str(e)}")
+        raise typer.Exit(1)
+
+@playbook_app.command("apply-delta")
+def playbook_apply_delta(
+    input_file: Optional[Path] = typer.Argument(None, help="JSON file containing delta operations (or use stdin)"),
+    dry_run: bool = typer.Option(False, "--dry-run", help="Preview changes without applying them")
+):
+    """Apply delta operations to playbook (ADD, UPDATE, DEPRECATE)
+
+    Accepts JSON from file or stdin with structure:
+    {
+      "operations": [
+        {
+          "type": "ADD",
+          "section": "IMPLEMENTATION_PATTERNS",
+          "content": "Pattern description...",
+          "code_example": "code here",
+          "helpful_count": 1,
+          "harmful_count": 0
+        },
+        {
+          "type": "UPDATE",
+          "bullet_id": "impl-0042",
+          "increment_helpful": 1,
+          "increment_harmful": 0
+        },
+        {
+          "type": "DEPRECATE",
+          "bullet_id": "impl-0099",
+          "reason": "Superseded by impl-0105"
+        }
+      ]
+    }
+
+    Examples:
+        mapify playbook apply-delta operations.json
+        mapify playbook apply-delta operations.json --dry-run
+        cat operations.json | mapify playbook apply-delta
+        echo '{"operations": [{"type": "UPDATE", "bullet_id": "impl-0001", "increment_helpful": 1}]}' | mapify playbook apply-delta
+
+    Exit codes:
+        0 - Operations applied successfully (or dry-run preview completed)
+        1 - Validation error or application failure
+    """
+    from mapify_cli.tools.validate_dependencies import load_input
+    from mapify_cli.playbook_manager import PlaybookManager
+
+    playbook_db_path = Path.cwd() / ".claude" / "playbook.db"
+    playbook_json_path = Path.cwd() / ".claude" / "playbook.json"
+
+    # Check for playbook.db first (primary storage)
+    if not playbook_db_path.exists():
+        # Backward compatibility: check if old playbook.json exists
+        if playbook_json_path.exists():
+            console.print("[red]Error:[/red] Found legacy playbook.json. Run 'mapify init' to migrate to playbook.db")
+        else:
+            console.print("[red]Error:[/red] Playbook not found. Initialize with 'mapify init'")
+        raise typer.Exit(1)
+
+    try:
+        # Load input from file or stdin
+        data = load_input(str(input_file) if input_file else None)
+
+        # Validate structure
+        if not isinstance(data, dict):
+            raise ValueError("Input must be a JSON object")
+
+        if "operations" not in data:
+            raise ValueError("Missing required field: 'operations'")
+
+        operations = data["operations"]
+        if not isinstance(operations, list):
+            raise ValueError("'operations' must be an array")
+
+        # Validate each operation
+        for i, op in enumerate(operations):
+            if not isinstance(op, dict):
+                raise ValueError(f"Operation {i} must be a JSON object")
+
+            op_type = op.get("type")
+            if not op_type:
+                raise ValueError(f"Operation {i} missing required field: 'type'")
+
+            if op_type not in ["ADD", "UPDATE", "DEPRECATE"]:
+                raise ValueError(f"Operation {i} has invalid type: {op_type} (must be ADD, UPDATE, or DEPRECATE)")
+
+            # Validate type-specific required fields
+            if op_type == "ADD":
+                required = ["section", "content"]
+                missing = [f for f in required if f not in op]
+                if missing:
+                    raise ValueError(f"ADD operation {i} missing required fields: {', '.join(missing)}")
+
+            elif op_type == "UPDATE":
+                if "bullet_id" not in op:
+                    raise ValueError(f"UPDATE operation {i} missing required field: 'bullet_id'")
+                if "increment_helpful" not in op and "increment_harmful" not in op:
+                    raise ValueError(f"UPDATE operation {i} must specify at least one of: increment_helpful, increment_harmful")
+
+            elif op_type == "DEPRECATE":
+                required = ["bullet_id", "reason"]
+                missing = [f for f in required if f not in op]
+                if missing:
+                    raise ValueError(f"DEPRECATE operation {i} missing required fields: {', '.join(missing)}")
+
+        # Dry-run mode: preview without applying
+        if dry_run:
+            # Count operations by type
+            add_count = sum(1 for op in operations if op.get("type") == "ADD")
+            update_count = sum(1 for op in operations if op.get("type") == "UPDATE")
+            deprecate_count = sum(1 for op in operations if op.get("type") == "DEPRECATE")
+
+            console.print_json(data={
+                "status": "dry_run",
+                "message": "DRY RUN - No changes applied",
+                "would_apply": {
+                    "total_operations": len(operations),
+                    "add": add_count,
+                    "update": update_count,
+                    "deprecate": deprecate_count
+                },
+                "operations": operations
+            })
+            return
+
+        # Apply operations
+        manager = PlaybookManager(db_path=str(playbook_db_path))
+        summary = manager.apply_delta(operations)
+
+        # Output JSON summary
+        console.print_json(data={
+            "status": "success",
+            "message": "Delta operations applied successfully",
+            "summary": summary
+        })
+
+    except ValueError as e:
+        console.print_json(data={
+            "status": "error",
+            "error_type": "validation_error",
+            "message": str(e)
+        })
+        raise typer.Exit(1)
+    except Exception as e:
+        console.print_json(data={
+            "status": "error",
+            "error_type": "unexpected_error",
+            "message": str(e)
+        })
+        raise typer.Exit(1)
+
 # Validate commands
 
 @validate_app.command("graph")
@@ -2007,4 +2439,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
