@@ -58,10 +58,14 @@ class RecitationManager:
         self.map_dir = self.project_root / ".map"
         self.plan_file = self.map_dir / "current_plan.md"
         self.plan_json = self.map_dir / "current_plan.json"
+        self.dev_docs_dir = self.map_dir / "dev_docs"
+        self.context_file = self.dev_docs_dir / "context.md"
+        self.tasks_file = self.dev_docs_dir / "tasks.md"
         self.logger = logger  # Optional logger for workflow tracking
 
-        # Create .map directory if it doesn't exist
+        # Create directories if they don't exist
         self.map_dir.mkdir(exist_ok=True)
+        self.dev_docs_dir.mkdir(exist_ok=True)
 
     def create_plan(self, task_id: str, goal: str, subtasks: List[dict], force: bool = False) -> TaskPlan:
         """
@@ -106,6 +110,7 @@ class RecitationManager:
 
         self._save_plan(plan)
         self._generate_markdown(plan)
+        self._generate_tasks_md(plan)  # Auto-generate tasks.md
 
         # Log plan creation
         if self.logger:
@@ -173,6 +178,7 @@ class RecitationManager:
 
         self._save_plan(plan)
         self._generate_markdown(plan)
+        self._generate_tasks_md(plan)  # Auto-regenerate tasks.md on update
 
         # Log status update
         if self.logger:
@@ -399,6 +405,256 @@ class RecitationManager:
             'updated_at': plan.updated_at
         }
 
+    def _generate_tasks_md(self, plan: TaskPlan):
+        """
+        Generate tasks.md file with current subtasks and their status.
+
+        This file is auto-updated whenever the recitation plan changes.
+        """
+        lines = [
+            f"# Tasks for: {plan.task_id}",
+            "",
+            f"**Overall Goal:** {plan.goal}",
+            "",
+            f"**Updated:** {datetime.now().strftime('%Y-%m-%d %H:%M:%S')}",
+            "",
+            "## Task List",
+            ""
+        ]
+
+        # Group tasks by status
+        pending = [st for st in plan.subtasks if st.status == 'pending']
+        in_progress = [st for st in plan.subtasks if st.status == 'in_progress']
+        completed = [st for st in plan.subtasks if st.status == 'completed']
+        failed = [st for st in plan.subtasks if st.status == 'failed']
+
+        # In Progress section (most important)
+        if in_progress:
+            lines.extend([
+                "### 🔄 In Progress",
+                ""
+            ])
+            for st in in_progress:
+                lines.append(f"- **[{st.id}]** {st.description}")
+                if st.acceptance_criteria:
+                    lines.append(f"  - **Acceptance:** {st.acceptance_criteria}")
+                if st.estimated_complexity:
+                    lines.append(f"  - **Complexity:** {st.estimated_complexity}")
+                if st.depends_on:
+                    lines.append(f"  - **Depends on:** {', '.join(map(str, st.depends_on))}")
+                if st.iterations > 1:
+                    lines.append(f"  - ⚠️ **Retry #{st.iterations}**")
+                if st.errors:
+                    lines.append(f"  - **Last Error:** {st.errors[-1][:150]}...")
+                lines.append("")
+
+        # Pending section
+        if pending:
+            lines.extend([
+                "### ☐ Pending",
+                ""
+            ])
+            for st in pending:
+                lines.append(f"- **[{st.id}]** {st.description}")
+                if st.depends_on:
+                    lines.append(f"  - **Depends on:** {', '.join(map(str, st.depends_on))}")
+                lines.append("")
+
+        # Completed section
+        if completed:
+            lines.extend([
+                "### ✓ Completed",
+                ""
+            ])
+            for st in completed:
+                lines.append(f"- ~~**[{st.id}]** {st.description}~~")
+                lines.append("")
+
+        # Failed section
+        if failed:
+            lines.extend([
+                "### ✗ Failed",
+                ""
+            ])
+            for st in failed:
+                lines.append(f"- **[{st.id}]** {st.description}")
+                if st.errors:
+                    lines.append(f"  - **Error:** {st.errors[-1][:150]}...")
+                lines.append("")
+
+        # Summary
+        total = len(plan.subtasks)
+        lines.extend([
+            "---",
+            "",
+            f"**Progress:** {len(completed)}/{total} completed, "
+            f"{len(in_progress)} in progress, "
+            f"{len(pending)} pending, "
+            f"{len(failed)} failed"
+        ])
+
+        self.tasks_file.write_text("\n".join(lines))
+
+    def generate_context_md(self):
+        """
+        Generate context.md file with project metadata and conventions.
+
+        This is typically run once or on-demand to capture project context.
+        """
+        lines = [
+            "# Project Context",
+            "",
+            "## Project Information",
+            ""
+        ]
+
+        # Try to read project info from README
+        readme_path = self.project_root / "README.md"
+        if readme_path.exists():
+            try:
+                readme_content = readme_path.read_text(encoding='utf-8')
+                # Extract title (first h1)
+                for line in readme_content.split('\n'):
+                    if line.startswith('# '):
+                        project_name = line[2:].strip()
+                        lines.append(f"**Project:** {project_name}")
+                        break
+
+                # Extract description (first paragraph after title)
+                in_description = False
+                description_lines = []
+                for line in readme_content.split('\n'):
+                    if line.startswith('# '):
+                        in_description = True
+                        continue
+                    if in_description and line.strip() and not line.startswith('#'):
+                        description_lines.append(line.strip())
+                    if in_description and (line.startswith('##') or len(description_lines) > 3):
+                        break
+
+                if description_lines:
+                    lines.append(f"**Description:** {' '.join(description_lines[:3])}")
+
+            except Exception as e:
+                lines.append(f"**Project:** (Could not read README.md: {e})")
+        else:
+            lines.append(f"**Project:** {self.project_root.name}")
+
+        lines.extend([
+            "",
+            f"**Location:** `{self.project_root}`",
+            "",
+            "## Key Conventions",
+            ""
+        ])
+
+        # Try to query playbook for high-quality patterns
+        try:
+            from mapify_cli.playbook_manager import PlaybookManager
+
+            playbook_db_path = self.project_root / ".claude" / "playbook.db"
+            playbook_json_path = self.project_root / ".claude" / "playbook.json"
+
+            # Check if playbook exists (prefer .db, fall back to .json for backward compatibility)
+            if playbook_db_path.exists() or playbook_json_path.exists():
+                playbook = PlaybookManager(
+                    playbook_path=str(playbook_json_path) if playbook_json_path.exists() else None,
+                    db_path=str(playbook_db_path)
+                )
+
+                # Get high-quality bullets (quality_score >= 5)
+                high_quality = playbook.get_bullets_for_sync(threshold=5)
+
+                if high_quality:
+                    lines.append("### Proven Patterns (from Playbook)")
+                    lines.append("")
+
+                    # Group by section and take top 3 per section
+                    from collections import defaultdict
+                    by_section = defaultdict(list)
+                    for bullet in high_quality:
+                        by_section[bullet['section']].append(bullet)
+
+                    # Sort each section by quality and take top 3
+                    for section_name, bullets in sorted(by_section.items()):
+                        bullets.sort(key=lambda b: b.get('quality_score', 0), reverse=True)
+                        top_bullets = bullets[:3]
+
+                        section_display = section_name.replace('_', ' ').title()
+                        lines.append(f"#### {section_display}")
+                        lines.append("")
+
+                        for bullet in top_bullets:
+                            # Truncate content if too long
+                            content = bullet['content']
+                            if len(content) > 200:
+                                content = content[:200] + "..."
+                            lines.append(f"- [{bullet['id']}] {content}")
+
+                        lines.append("")
+                else:
+                    lines.append("*(No high-quality patterns in playbook yet)*")
+                    lines.append("")
+
+        except Exception as e:
+            lines.append(f"*(Could not load playbook patterns: {e})*")
+            lines.append("")
+
+        # Add architecture section
+        arch_path = self.project_root / "ARCHITECTURE.md"
+        if arch_path.exists():
+            lines.extend([
+                "## Architecture Overview",
+                "",
+                f"See [ARCHITECTURE.md]({arch_path.relative_to(self.project_root)}) for details.",
+                ""
+            ])
+
+        # Add common gotchas section
+        lines.extend([
+            "## Common Gotchas",
+            "",
+            "*(This section should be manually updated as you discover pitfalls)*",
+            "",
+            "---",
+            "",
+            f"*Last generated: {datetime.now().strftime('%Y-%m-%d %H:%M:%S')}*"
+        ])
+
+        self.context_file.write_text("\n".join(lines))
+
+        return str(self.context_file)
+
+    def get_dev_docs(self) -> dict:
+        """
+        Get all dev docs content for Claude injection.
+
+        Returns a dict with plan, context, and tasks content.
+        """
+        result = {
+            "plan": "",
+            "context": "",
+            "tasks": ""
+        }
+
+        # Read plan.md (current_plan.md)
+        if self.plan_file.exists():
+            result["plan"] = self.plan_file.read_text(encoding='utf-8')
+
+        # Read context.md
+        if self.context_file.exists():
+            result["context"] = self.context_file.read_text(encoding='utf-8')
+        else:
+            result["context"] = "# Context\n\n*(Not generated yet. Run `mapify recitation generate-context`)*"
+
+        # Read tasks.md
+        if self.tasks_file.exists():
+            result["tasks"] = self.tasks_file.read_text(encoding='utf-8')
+        else:
+            result["tasks"] = "# Tasks\n\n*(No active plan)*"
+
+        return result
+
 
 # CLI interface
 if __name__ == "__main__":
@@ -416,6 +672,9 @@ if __name__ == "__main__":
         print("  mapify recitation get-context")
         print("  mapify recitation stats")
         print("  mapify recitation clear")
+        print("  mapify recitation generate-context")
+        print("  mapify recitation generate-tasks")
+        print("  mapify recitation get-docs")
         print("\nExamples:")
         print("  # Create plan")
         print('  mapify recitation create feat_auth "Add JWT auth" \'[{"id":1,"description":"Create model",...}]\'')
@@ -431,6 +690,10 @@ if __name__ == "__main__":
         print("  mapify recitation stats")
         print("\n  # Clear plan")
         print("  mapify recitation clear")
+        print("\n  # Generate dev docs")
+        print("  mapify recitation generate-context  # Generate context.md from README and playbook")
+        print("  mapify recitation generate-tasks    # Regenerate tasks.md from current plan")
+        print("  mapify recitation get-docs          # Get all dev docs (plan + context + tasks)")
         sys.exit(1)
 
     command = sys.argv[1]
@@ -443,6 +706,9 @@ if __name__ == "__main__":
         print("  mapify recitation get-context")
         print("  mapify recitation stats")
         print("  mapify recitation clear")
+        print("  mapify recitation generate-context")
+        print("  mapify recitation generate-tasks")
+        print("  mapify recitation get-docs")
         print("\nOptions:")
         print("  --force    Overwrite existing plan when using 'create' command")
         print("\nExamples:")
@@ -460,6 +726,10 @@ if __name__ == "__main__":
         print("  mapify recitation stats")
         print("\n  # Clear plan")
         print("  mapify recitation clear")
+        print("\n  # Generate dev docs")
+        print("  mapify recitation generate-context  # Generate context.md from README and playbook")
+        print("  mapify recitation generate-tasks    # Regenerate tasks.md from current plan")
+        print("  mapify recitation get-docs          # Get all dev docs (plan + context + tasks)")
         sys.exit(0)
 
     manager = RecitationManager(Path.cwd())
@@ -545,6 +815,58 @@ if __name__ == "__main__":
             "message": "Plan cleared"
         }, indent=2))
 
+    elif command == "generate-context":
+        try:
+            context_file = manager.generate_context_md()
+            print(json.dumps({
+                "status": "success",
+                "message": "Generated context.md",
+                "file": context_file
+            }, indent=2))
+        except Exception as e:
+            print(json.dumps({
+                "status": "error",
+                "message": f"Failed to generate context.md: {str(e)}"
+            }, indent=2))
+            sys.exit(1)
+
+    elif command == "generate-tasks":
+        try:
+            plan = manager.get_plan()
+            if not plan:
+                print(json.dumps({
+                    "status": "error",
+                    "message": "No active plan to generate tasks from"
+                }, indent=2))
+                sys.exit(1)
+
+            manager._generate_tasks_md(plan)
+            print(json.dumps({
+                "status": "success",
+                "message": "Generated tasks.md",
+                "file": str(manager.tasks_file)
+            }, indent=2))
+        except Exception as e:
+            print(json.dumps({
+                "status": "error",
+                "message": f"Failed to generate tasks.md: {str(e)}"
+            }, indent=2))
+            sys.exit(1)
+
+    elif command == "get-docs":
+        try:
+            docs = manager.get_dev_docs()
+            print(json.dumps({
+                "status": "success",
+                "docs": docs
+            }, indent=2))
+        except Exception as e:
+            print(json.dumps({
+                "status": "error",
+                "message": f"Failed to get dev docs: {str(e)}"
+            }, indent=2))
+            sys.exit(1)
+
     else:
         print(f"Error: Unknown command '{command}'")
         print("Run without arguments to see usage")
